R/checklink.R
checklink.RdThis function is used within the distribution family specification of a GAMLSS model to define the right link for each of the parameters of the distribution. This function should not be called by the user unless he/she specify a new distribution family or wishes to change existing link functions in the parameters.
checklink(which.link = NULL, which.dist = NULL, link = NULL, link.List = NULL)Defines the right link for each parameter.
This function is the same checklink fuction from gamlss.dist package.